Attribute VB_Name = "Module1"
Option Explicit

Public Type PROCESSENTRY32
    dwSize              As Long ' The length in bytes of the structure
    cntUsage            As Long ' The number of references to the process
    th32ProcessID       As Long ' Identifier of the process
    th32DefaultHeapID   As Long ' Identifier of the default heap for the process
    th32ModuleID        As Long ' Identifier of the process's module
    cntThreads          As Long ' The number of threads started by the program
    th32ParentProcessID As Long ' The identifier of the process that created this process
    pcPriClassBase      As Long ' The base priority by any threads created by this class
    dwFlags             As Long
    szExeFile           As String * 260 ' The filename of the executable file for the process
End Type

'CreateToolhelp32Snapshot creates a snapshot of what is running on the computer the moment the function is called.
Public Declare Function CreateToolhelp32Snapshot Lib "kernel32.dll" ( _
               ByVal dwFlags As Long, _
               ByVal th32ProcessID As Long) As Long

'Process32First retrieves information about the first process in the process list contained in a system snapshot.
Public Declare Function Process32First Lib "kernel32.dll" ( _
               ByVal hSnapshot As Long, _
               lppe As PROCESSENTRY32) As Long

'Process32Next retrieves information about the next unread process in the process list contained in a system snapshot.
Public Declare Function Process32Next Lib "kernel32.dll" ( _
               ByVal hSnapshot As Long, _
               lppe As PROCESSENTRY32) As Long

'CloseHandle closes a handle and the object associated with that handle.
Public Declare Function CloseHandle Lib "kernel32.dll" ( _
               ByVal hObject As Long) As Long
               
'Include the process list in the snapshot
Public Const TH32CS_SNAPPROCESS As Long = &H2

Public Sub ListProcesses()
    Dim processInfo As PROCESSENTRY32   ' information about a process in that list
    Dim hSnapshot   As Long             ' handle to the snapshot of the process list
    Dim success     As Long             ' success of having gotten info on another process
    Dim retval      As Long             ' generic return value
    Dim exeName     As String           ' filename of the process
    
    ' First, make a snapshot of the current process list.
    hSnapshot = CreateToolhelp32Snapshot(TH32CS_SNAPPROCESS, 0)
    
    ' Get information about the first process in the list.
    processInfo.dwSize = Len(processInfo)
    success = Process32First(hSnapshot, processInfo)
    
    ' Make sure a handle was returned.
    If hSnapshot = -1 Then
        Debug.Print "Unable to take snapshot of process list!"
    Else
        ' Loop for each process on the list.
        Do While success <> 0
            ' Extract the filename of the process (i.e., remove the empty space)
            exeName = Left(processInfo.szExeFile, InStr(processInfo.szExeFile, vbNullChar) - 1)
            
            ' Display the process name
            Debug.Print "Process: "; exeName
            
            ' Get information about the next process, if there is one.
            processInfo.dwSize = Len(processInfo)
            success = Process32Next(hSnapshot, processInfo)
        Loop
        
        ' Destroy the snapshot, now that we no longer need it.
        retval = CloseHandle(hSnapshot)
    End If
End Sub
